@@ -32,6 +32,11 @@ def _TraitsDict(traits: dict, trait_map: dict, cmd: Command):
     return d
 
 
-def BuildTraits(traits: dict, cmd: Command) -> dict:
+def BuildTraits(traits: dict, cmd: Command, device_type=None) -> dict:
     """Builds a trait map out of a response dict."""
+    # There is a bug where doorbells do not return the DoorbellChime trait.  Simulate
+    # that it was returned
+    if device_type and device_type == "sdm.devices.types.DOORBELL":
+        traits = traits.copy()
+        traits["sdm.devices.traits.DoorbellChime"] = {}
     return _TraitsDict(traits, TRAIT_MAP, cmd)
